@@ -48,9 +48,6 @@ _toolkit = None
 #-------------------------------------------------------------------------------
 
 def _import_toolkit ( name ):
-    if name == "wx":
-        import wxversion
-        wxversion.select("2.8")
     return __import__( name, globals=globals(), level=1 ).toolkit
 
 
